/*
 *
 * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-1999
 *
 * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
 *
 */

#ifndef _VLIB_H_
#define _VLIB_H_

#include <target.h> // this must set _TARGET_XXX_ define

#include <clusters.h>
#include <vstring.h>
#include <vstrlib.h>
#include <fnmatch2.h>
#include <getopt2.h>
#include <regexp2.h>
#include <vsuti.h>
#include <dlog.h>
#include <unicon.h>
#include <scroll.h>
#include <form_in.h>
#include <conmenu.h>

#endif //_VLIB_H_

 // eof vlib.h

